@@ -7,13 +7,15 @@ import logging
 import getpass
 import tempfile
 
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 __author__ = 'Marco Lovato'
 __author_username__ = 'lovato'
 __author_email__ = 'maglovato@gmail.com'
-__description__ = 'A command-line tool to create projects from templates, to start your python work.'
+__description__ = 'A command-line tool to create projects \
+                  from templates, to start your python work.'
 
-log_filename = os.path.join(tempfile.gettempdir(), 'machete-' + getpass.getuser() + '.log')
+log_filename = os.path.join(tempfile.gettempdir(),
+                            'machete-' + getpass.getuser() + '.log')
 
 log = logging
 log.basicConfig(level=logging.DEBUG,
@@ -25,6 +27,11 @@ log.basicConfig(level=logging.DEBUG,
 def __path(filename):
     return os.path.join(os.path.dirname(os.path.realpath(__file__)), filename)
 
+if os.getenv("TRAVIS_BUILD_NUMBER"):
+    file_ = open(__path('build.info'), 'w')
+    file_.write(os.getenv("TRAVIS_BUILD_NUMBER"))
+    file_.close()
+
 if os.path.exists(__path('build.info')):
     __build__ = open(__path('build.info')).read().strip()
 else:
